function varargout = settingsui(varargin)
% SETTINGSUI MATLAB code for settingsui.fig
%      SETTINGSUI, by itself, creates a new SETTINGSUI or raises the existing
%      singleton*.
%
%      H = SETTINGSUI returns the handle to a new SETTINGSUI or the handle to
%      the existing singleton*.
%
%      SETTINGSUI('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in SETTINGSUI.M with the given input arguments.
%
%      SETTINGSUI('Property','Value',...) creates a new SETTINGSUI or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before settingsui_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to settingsui_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help settingsui

% Last Modified by GUIDE v2.5 11-Jun-2012 15:57:30

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @settingsui_OpeningFcn, ...
                   'gui_OutputFcn',  @settingsui_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before settingsui is made visible.
function settingsui_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to settingsui (see VARARGIN)

% Choose default command line output for settingsui
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes settingsui wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = settingsui_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in ledsonconnect.
function ledsonconnect_Callback(hObject, eventdata, handles)
% hObject    handle to ledsonconnect (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of ledsonconnect
x = get(handles.figure1, 'UserData');
x.acquireconnect = get(hObject, 'Value');
x.SaveSettings();


% --- Executes on button press in programsonconnect.
function programsonconnect_Callback(hObject, eventdata, handles)
% hObject    handle to programsonconnect (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of programsonconnect
x = get(handles.figure1, 'UserData');
x.loadprogramconnect = get(hObject, 'Value');
x.SaveSettings();


% --- Executes on button press in stoponconnect.
function stoponconnect_Callback(hObject, eventdata, handles)
% hObject    handle to stoponconnect (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of stoponconnect
x = get(handles.figure1, 'UserData');
x.stopconnect = get(hObject, 'Value');
x.SaveSettings();

% --- Executes on button press in autopause.
function autopause_Callback(hObject, eventdata, handles)
% hObject    handle to autopause (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of autopause
x = get(handles.figure1, 'UserData');
x.autopause = get(hObject, 'Value');
x.SaveSettings();


% --- Executes when user attempts to close figure1.
function figure1_CloseRequestFcn(hObject, eventdata, handles)
% hObject    handle to figure1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: delete(hObject) closes the figure
% delete(hObject);
set(handles.figure1, 'Visible', 'off');